django-writingfield
-------------------

|Coverage Status|

|Build Status|

`There is a demo running that you can try <http://django-writingfield-demo.herokuapp.com/>`__.


django-writingfield is a custom form widget to enhances textareas in the django admin to give them a delicious fullscreen writing mode.

For more information `read the docs <http://django-writingfield.readthedocs.org>`__

Submitting pull requests
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Pull requests are super welcome, but please make sure to they're aimed to the develop branch : ) 


Development - setting up Grunt
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

django-writingfield uses grunt for building, packaging and watching js/scss. If you want
to hack on django-writingfield then you'll find it hyper useful.


|bitdeli|


.. |Coverage Status| image:: https://coveralls.io/repos/jamiecurle/django-writingfield/badge.png?branch=develop
.. |Build Status| image:: https://jenkins.curle.io/buildStatus/icon?job=django-writingfield-django-1.6.1

.. |bitdeli| image:: https://d2weczhvl823v0.cloudfront.net/jamiecurle/django-writingfield/trend.png
